==> Game-Linux-0.2.tar.gz: Game/main.h <==
#include <GL/gl.h>
#include <GL/glu.h>
#include <SDL/SDL.h>
#include <iostream>
#include <math.h>

using namespace std;

typedef struct tVector3
{
        tVector3() {}
        tVector3 (float new_x, float new_y, float new_z)
        {x = new_x; y = new_y; z = new_z;}
        tVector3 operator+(tVector3 vVector) {return tVector3(vVector.x+x, vVector.y+y, vVector.z+z);}
        tVector3 operator-(tVector3 vVector) {return tVector3(x-vVector.x, y-vVector.y, z-vVector.z);}
        tVector3 operator*(float number)         {return tVector3(x*number, y*number, z*number);}
        tVector3 operator/(float number)         {return tVector3(x/number, y/number, z/number);}
        float x, y, z;
}tVector3;

class Camera
{
public:
        void setCameraPosition(float pos_x, float pos_y, float pos_z,
                               float view_x, float view_y, float view_z,
                               float up_x, float up_y, float up_z);
	
        void moveMouse();
        void moveCamera(float speed);
        void strafeCamera(float speed);
        void rotateCamera(float speed);

        tVector3 mPos;
        tVector3 mView;
        tVector3 mUp;
};

class Player
{
public:
        void setPlayerPosition(float px, float py, float pz,
                               float vx, float vy, float vz);

        void setHealth(int HP);
        int getHealth();

	void setTeam(int pTeam);
	int getTeam();

        void movePlayer(float direction);
        void strafePlayer(float direction);

        //void addVelocity(float xVel, float yVel, float zVel);

        tVector3 pPos;
        tVector3 pView;
        //tVector3 pVel;
        int HP;
	int pTeam;
};

class AI
{
public:
	void setAIPosition(float ax, float ay, float az,
			   float avx, float avy, float avz);

	void setAIHealth(int aiHP);
	int getAIHealth();
	
	//May be adding a move to the target thing?
	//I also have to get some pathfinding stuff in here.
	void moveAI(float direction);
	void strafeAI(float direction);

	//void setTarget(<var type> target);
	//<var type>  getTarget();

	void setTeam(int aTeam);
	int getTeam();

	tVector3 aPos;
	tVector3 aView;
	//tVector3 aVel;
	int aiHP;
	int aTeam;
};

==> Game-Linux-0.12.tar.gz: Game/main.h <==
#include <GL/gl.h>
#include <GL/glu.h>
#include <SDL/SDL.h>
#include <iostream>
#include <math.h>

using namespace std;

typedef struct tVector3
{
        tVector3() {}
        tVector3 (float new_x, float new_y, float new_z)
        {x = new_x; y = new_y; z = new_z;}
        tVector3 operator+(tVector3 vVector) {return tVector3(vVector.x+x, vVector.y+y, vVector.z+z);}
        tVector3 operator-(tVector3 vVector) {return tVector3(x-vVector.x, y-vVector.y, z-vVector.z);}
        tVector3 operator*(float number)         {return tVector3(x*number, y*number, z*number);}
        tVector3 operator/(float number)         {return tVector3(x/number, y/number, z/number);}
        float x, y, z;
}tVector3;

class Camera
{
public:
        void setCameraPosition(float pos_x, float pos_y, float pos_z,
                               float view_x, float view_y, float view_z,
                               float up_x, float up_y, float up_z);
	
        void moveMouse();
        void moveCamera(float speed);
        void strafeCamera(float speed);
        void rotateCamera(float speed);

        tVector3 mPos;
        tVector3 mView;
        tVector3 mUp;
};

class Player
{
public:
        void setPlayerPosition(float px, float py, float pz,
                               float vx, float vy, float vz);

        void setHealth(int HP);
        int getHealth();

	void setTeam(int pTeam);
	int getTeam();

        void movePlayer(float direction);
        void strafePlayer(float direction);

        //void addVelocity(float xVel, float yVel, float zVel);

        tVector3 pPos;
        tVector3 pView;
        //tVector3 pVel;
        int HP;
	int pTeam;
};

class AI
{
public:
	void setAIPosition(float ax, float ay, float az,
			   float avx, float avy, float avz);

	void setAIHealth(int aiHP);
	int getAIHealth();
	
	//May be adding a move to the target thing?
	//I also have to get some pathfinding stuff in here.
	void moveAI(float direction);
	void strafeAI(float direction);

	//void setTarget(<var type> target);
	//<var type>  getTarget();

	void setTeam(int aTeam);
	int getTeam();
	
	//The 3D model function here. This is new shit. Need to learn.
	void setModel()//insert the parameter here. Because I'm lazy
	{
		
	}
	
	tVector3 aPos;
	tVector3 aView;
	//tVector3 aVel;
	int aiHP;
	int aTeam;
};
